@@ -1,5 +1,5 @@
 package SVN::Notify::Config;
-$SVN::Notify::Config::VERSION = '0.02';
+$SVN::Notify::Config::VERSION = '0.03';
 
 use strict;
 use YAML;
@@ -11,8 +11,8 @@ SVN::Notify::Config - Config-driven Subversion notification
 
 =head1 VERSION
 
-This document describes version 0.02 of SVN::Notify::Config,
-released October 17, 2004.
+This document describes version 0.03 of SVN::Notify::Config,
+released October 18, 2004.
 
 =head1 SYNOPSIS
 
@@ -36,6 +36,10 @@ Set this as your Subversion repository's F<hooks/post-commit>:
    - to: bob@localhost
    - to: root@localhost
 
+Alternatively, use a config file inside the repository:
+
+ #!/usr/bin/perl -MSVN::Notify::Config=file://$1/svnnotify.yml
+
 =head1 DESCRIPTION
 
 This module is a is a YAML-based configuration wrapper on L<SVN::Notify>.
@@ -46,27 +50,57 @@ This module is a is a YAML-based configuration wrapper on L<SVN::Notify>.
 
 sub import {
     my $class = shift;
-    my $config = shift or return;
+    my @config = @_ or return;
 
-    $config =~ s/\$0/$0/g;
-    $config =~ s/\$(\d+)/$ARGV[$1-1]/eg;
+    foreach my $config (@config) {
+        $config =~ s/\$0/$0/g;
+        $config =~ s/\$(\d+)/$ARGV[$1-1]/eg;
 
-    my $self = $class->new($config);
+        my $self = $class->new($config);
 
-    $self->prepare;
-    $self->execute(
-        repos_path  => $ARGV[0],
-        revision    => $ARGV[1],
-    );
+        $self->prepare;
+        $self->execute(
+            repos_path  => $ARGV[0],
+            revision    => $ARGV[1],
+        );
+    }
 
     exit;
 }
 
 sub new {
     my ($class, $config) = @_;
-    bless( YAML::LoadFile( $config ), $class );
+    bless(
+        ($config =~ m{^[A-Za-z][-+.A-Za-z0-9]*://}
+            ? YAML::Load(scalar `svn cat $config`)
+            : YAML::LoadFile( $config )),
+        $class,
+    );
 }
 
+
+sub prepare {
+    my ($self) = @_;
+
+    # Heuristic: if none of our values are refs, cast it into ''.
+    $self = { '' => { %$self } } unless grep ref, values %$self;
+
+    my @keys = sort keys %$self;
+    foreach my $key (@keys) {
+        next if UNIVERSAL::isa( $self->{$key} => 'ARRAY' );
+        $self->{$key} = [ { %{ $self->{$key} } } ];
+    }
+
+    foreach my $key (@keys) {
+        foreach my $value (@{ $self->{$key} }) {
+            my @vkeys = sort keys %$value;
+            foreach my $vkey (@vkeys) {
+                $vkey =~ /-/ or next;
+                $value->{$self->_normalize_key($vkey)} = delete $value->{$vkey};
+            }
+        }
+    }
+}
 sub execute {
     my ($self, %args) = @_;
 
@@ -78,7 +112,7 @@ sub execute {
     my $filter = SVN::Notify->new(
         %args,
         to_regex_map => {
-            map { +( $_ => $keys[$_] ) } 0..$#keys
+            map { +( $_ => $keys[$_] ) } (0 .. $#keys)
         },
     );
     $filter->prepare_recipients;
@@ -99,7 +133,7 @@ sub execute {
         foreach my $key (sort keys %$value) {
             my $vval = $value->{$key};
             $vval =~ s{\$\{([-\w]+)\}}
-                      {$value->{$self->normalize_key($1)}}eg or next;
+                      {$value->{$self->_normalize_key($1)}}eg or next;
             $value->{$key} = $vval;
         }
 
@@ -109,30 +143,7 @@ sub execute {
     }
 }
 
-sub prepare {
-    my ($self) = @_;
-
-    # Heuristic: if none of our values are refs, cast it into ''.
-    $self = { '' => { %$self } } unless grep ref, values %$self;
-
-    my @keys = sort keys %$self;
-    foreach my $key (@keys) {
-        next if UNIVERSAL::isa( $self->{$key} => 'ARRAY' );
-        $self->{$key} = [ { %{ $self->{$key} } } ];
-    }
-
-    foreach my $key (@keys) {
-        foreach my $value (@{ $self->{$key} }) {
-            my @vkeys = sort keys %$value;
-            foreach my $vkey (@vkeys) {
-                $vkey =~ /-/ or next;
-                $value->{$self->normalize_key($vkey)} = delete $value->{$vkey};
-            }
-        }
-    }
-}
-
-sub normalize_key {
+sub _normalize_key {
     my ($self, $key) = @_;
     $key =~ s/-/_/g;
     return $key;
